@@ -70,9 +70,15 @@ my %processByMetaFormat = (
 
 # data lengths for each INSV record type
 my %insvDataLen = (
-    0x300 => 56,
-    0x400 => 16,
-    0x700 => 53,
+    0x300 => 56,    # accelerometer
+    0x400 => 16,    # unknown
+    0x700 => 53,    # GPS
+);
+
+# limit the default amount of data we read for some record types
+# (to avoid running out of memory)
+my %insvLimit = (
+    0x300 => [ 'accelerometer', 20000 ],    # maximum of 20000 accelerometer records
 );
 
 # tags extracted from various QuickTime data streams
@@ -910,6 +916,23 @@ sub ProcessFreeGPS($$$)
             map { $_ = $_ - 4294967296 if $_ >= 0x80000000; $_ /= 256 } @acc;
         }
 
+    } elsif ($$dataPt =~ /^.{40}A([NS])([EW])/s) {
+
+        # decode freeGPS from ViofoA119v3 dashcam (similar to Novatek GPS format)
+        # 0000: 00 00 40 00 66 72 65 65 47 50 53 20 f0 03 00 00 [..@.freeGPS ....]
+        # 0010: 05 00 00 00 2f 00 00 00 03 00 00 00 13 00 00 00 [..../...........]
+        # 0020: 09 00 00 00 1b 00 00 00 41 4e 57 00 25 d1 99 45 [........ANW.%..E]
+        # 0030: f1 47 40 46 66 66 d2 41 85 eb 83 41 00 00 00 00 [.G@Fff.A...A....]
+        ($latRef, $lonRef) = ($1, $2);
+        ($hr,$min,$sec,$yr,$mon,$day) = unpack('x16V6', $$dataPt);
+        $yr += 2000;
+        SetByteOrder('II');
+        $lat = GetFloat($dataPt, 0x2c);
+        $lon = GetFloat($dataPt, 0x30);
+        $spd = GetFloat($dataPt, 0x34) * 1.852; # (convert knots to km/h)
+        $trk = GetFloat($dataPt, 0x38);
+        SetByteOrder('MM');
+
     } else {
 
         # decode binary GPS format (Viofo A119S, ref 2)
@@ -1375,7 +1398,7 @@ sub Process_mebx($$$)
 }
 
 #------------------------------------------------------------------------------
-# Process QuickTime '3gf' timed metadata (Pittasoft Blackvue dashcam)
+# Process QuickTime '3gf' timed metadata (ref PH, Pittasoft Blackvue dashcam)
 # Inputs: 0) ExifTool ref, 1) dirInfo ref, 2) tag table ref
 # Returns: 1 on success
 sub Process_3gf($$$)
@@ -1635,7 +1658,7 @@ sub ProcessTTAD($$$)
 }
 
 #------------------------------------------------------------------------------
-# Extract information from Insta360 trailer
+# Extract information from Insta360 trailer (ref PH)
 # Inputs: 0) ExifTool ref
 sub ProcessINSVTrailer($)
 {
@@ -1650,23 +1673,29 @@ sub ProcessINSVTrailer($)
     my $tagTbl = GetTagTable('Image::ExifTool::QuickTime::Stream');
     my $fileEnd = $raf->Tell();
     my $trailerLen = unpack('x38V', $buff);
-    my $trailerStart = $fileEnd - $trailerLen;
+    $trailerLen > $fileEnd and $et->Warn('Bad INSV trailer size'), return;
     my $unknown = $et->Options('Unknown');
     my $verbose = $et->Options('Verbose');
-    my $pos = $fileEnd - 78;
+    my $epos = -78;   # position relative to EOF (avoids using large offsets for files > 2 GB)
     my ($i, $p);
     SetByteOrder('II');
     # loop through all records in the trailer, from last to first
     for (;;) {
         my ($id, $len) = unpack('vV', $buff);
-        ($pos -= $len) < $trailerStart and last;
-        $raf->Seek($pos, 0) or last;
-        $raf->Read($buff, $len) == $len or last;
-        if ($verbose) {
-            $et->VPrint(0, sprintf("INSV Record 0x%x (offset 0x%x, %d bytes):\n", $id, $pos, $len));
-            $et->VerboseDump(\$buff);
-        }
+        ($epos -= $len) + $trailerLen < 0 and last;
+        $raf->Seek($epos, 2) or last;
         my $dlen = $insvDataLen{$id};
+        if ($verbose) {
+            $et->VPrint(0, sprintf("INSV Record 0x%x (offset 0x%x, %d bytes):\n", $id, $fileEnd + $epos, $len));
+        }
+        # limit the number of records we read if necessary
+        if ($insvLimit{$id} and $len > $insvLimit{$id}[1] * $dlen and
+            $et->Warn("INSV $insvLimit{$id}[0] data is huge. Processing only the first $insvLimit{$id}[1] records",2))
+        {
+            $len = $insvLimit{$id}[1] * $dlen;
+        }
+        $raf->Read($buff, $len) == $len or last;
+        $et->VerboseDump(\$buff) if $verbose > 2;
         if ($dlen) {
             $len % $dlen and $et->Warn(sprintf('Unexpected INSV record 0x%x length',$id)), last;
             if ($id == 0x300) {
@@ -1692,8 +1721,8 @@ sub ProcessINSVTrailer($)
                                 ($a[7] eq 'E' or $a[7] eq 'W');
                     $$et{DOC_NUM} = ++$$et{DOC_COUNT};
                     $a[$_] = GetDouble(\$a[$_], 0) foreach 4,6,8,9,10;
-                    $a[4] *= -abs($a[4]) if $a[5] eq 'S'; # (abs just in case it was already signed)
-                    $a[6] *= -abs($a[6]) if $a[7] eq 'W';
+                    $a[4] = -abs($a[4]) if $a[5] eq 'S'; # (abs just in case it was already signed)
+                    $a[6] = -abs($a[6]) if $a[7] eq 'W';
                     $et->HandleTag($tagTbl, GPSDateTime => Image::ExifTool::ConvertUnixTime($a[0]) . 'Z');
                     $et->HandleTag($tagTbl, GPSLatitude => $a[4]);
                     $et->HandleTag($tagTbl, GPSLongitude => $a[6]);
@@ -1702,7 +1731,7 @@ sub ProcessINSVTrailer($)
                     $et->HandleTag($tagTbl, GPSTrack => $a[9]);
                     $et->HandleTag($tagTbl, GPSTrackRef => 'T');
                     $et->HandleTag($tagTbl, GPSAltitude => $a[10]);
-                    $et->HandleTag($tagTbl, Unknown02 => "@a[1,2]");
+                    $et->HandleTag($tagTbl, Unknown02 => "@a[1,2]") if $unknown;
                 }
             }
         } elsif ($id == 0x101) {
@@ -1716,8 +1745,8 @@ sub ProcessINSVTrailer($)
                 $p += 2 + $n;
             }
         }
-        ($pos -= 6) < $trailerStart and last;   # step back to previous record
-        $raf->Seek($pos, 0) or last;
+        ($epos -= 6) + $trailerLen < 0 and last;    # step back to previous record
+        $raf->Seek($epos, 2) or last;
         $raf->Read($buff, 6) == 6 or last;
     }
     SetByteOrder('MM');
